==> civicrm_4.7.30+dfsg.orig.tar.xz: civicrm/CRM/Upgrade/StateMachine.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 4.7                                                |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2017                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2017
 */

/**
 * State machine for managing different states of the upgrade process.
 */
class CRM_Upgrade_StateMachine extends CRM_Core_StateMachine {

  /**
   * Class constructor.
   *
   * @param CRM_Upgrade_Controller $controller
   * @param array $pages
   * @param int $action
   *
   * @return CRM_Upgrade_StateMachine
   */
  public function __construct(&$controller, &$pages, $action = CRM_Core_Action::NONE) {
    parent::__construct($controller, $action);

    $this->_pages = &$pages;

    $this->addSequentialPages($this->_pages, $action);
  }

}

==> civicrm_5.6.0+dfsg.orig.tar.xz: civicrm/CRM/Upgrade/StateMachine.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2018                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2018
 */

/**
 * State machine for managing different states of the upgrade process.
 */
class CRM_Upgrade_StateMachine extends CRM_Core_StateMachine {

  /**
   * Class constructor.
   *
   * @param CRM_Upgrade_Controller $controller
   * @param array $pages
   * @param int $action
   *
   * @return CRM_Upgrade_StateMachine
   */
  public function __construct(&$controller, &$pages, $action = CRM_Core_Action::NONE) {
    parent::__construct($controller, $action);

    $this->_pages = &$pages;

    $this->addSequentialPages($this->_pages, $action);
  }

}
